package Bar;
use Function::Interface::Impl qw(IBar);

fun bar() :Return() { }

1;
